#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-4YRKA1OerJdEvugkEBCTLd
key:                  persistent-test-2.13.1.3-4YRKA1OerJdEvugkEBCTLd
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  3bd4391a02a2e26016824c157d89c07b
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-4YRKA1OerJdEvugkEBCTLd
depends:
    HUnit-1.6.2.0-L1r9G4r6Tqe7YoPeBDc5p3
    QuickCheck-2.15.0.1-HW6HIMYjXnYB7OQUyImYOa
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1
    blaze-html-0.9.2.0-FHozDOQfWbTE40Bgc3es6n bytestring-0.11.5.3
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED containers-0.6.7
    exceptions-0.10.7 hspec-2.11.7-IufmvTkKFuhK8Sz3dfXkFn
    hspec-expectations-0.8.4-KDdqNp0px8sIhjWBtMxbQb
    http-api-data-0.6.1-5rw4rYexF9LBK7T8HJM8P8
    monad-control-1.0.3.1-JD20Nk0MZISXRupR36zqX
    monad-logger-0.3.42-9nXe4zEtCrVBsRKA8Lng7G mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.6.1-GEU3f5Qg3bVH7PMKZ9qrSb
    quickcheck-instances-0.3.33-62I6bbUbZnsHHyfvQZ7K3D
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    resourcet-1.3.0-G1Jndw6mtoEGFSzuHCFgbA text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-KVGmi18zWpVBHzJbJXeH1j
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

